aboutsummaryrefslogtreecommitdiff
path: root/build2/config/operation.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'build2/config/operation.cxx')
-rw-r--r--build2/config/operation.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/build2/config/operation.cxx b/build2/config/operation.cxx
index e10030a..1e6a387 100644
--- a/build2/config/operation.cxx
+++ b/build2/config/operation.cxx
@@ -891,9 +891,9 @@ namespace build2
// Start with process parameters. The first parameter, if any, is a list
// of root.build modules. The second parameter, if any, is a list of
// bootstrap.build modules. If the second is not specified, then the
// default is test and install (config is mandatory).
//
- strings bmod {"test", "install"};
+ strings bmod {"test", "dist", "install"};
strings rmod;
try
{
@@ -891,9 +891,9 @@ namespace build2
// of root.build modules. The second parameter, if any, is a list of
// bootstrap.build modules. If the second is not specified, then the
- // default is test and install (config is mandatory).
+ // default is test, dist, and install (config is mandatory).
//